local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not vim.loop.fs_stat(lazypath) then
	vim.fn.system({
		"git",
		"clone",
		"--filter=blob:none",
		"https://github.com/folke/lazy.nvim.git",
		"--branch=stable", -- latest stable release
		lazypath,
	})
end
vim.opt.rtp:prepend(lazypath)

-- Install your plugins here
local plugins = {

	-- tmux integrations
	'alexghergh/nvim-tmux-navigation',

	-- "gc" to comment visual regions/lines
	'numToStr/Comment.nvim',

	-- FZF
	{
		'nvim-telescope/telescope.nvim', version = '0.1.5',
		-- or                              , branch = '0.1.x',
		dependencies = { 'nvim-lua/plenary.nvim' }
	},
	{ 'nvim-telescope/telescope-fzf-native.nvim', build = 'make' },

	--Colortheme
	{
		'rose-pine/neovim',
		name = "rose-pine",
		config = function()
			vim.cmd('colorscheme rose-pine')
		end
	},

	-- Fancier statusline
	'nvim-lualine/lualine.nvim',

	-- Add git related info in the signs columns and popups
	'lewis6991/gitsigns.nvim',

	-- Surround '"{[(
	'ur4ltz/surround.nvim',

	-- Fancy view file for neomutt
	{
		'folke/zen-mode.nvim',
		config = function()
			require("zen-mode").setup {
				-- your configuration comes here
				-- or leave it empty to use the default settings
				-- refer to the configuration section below
			}
		end
	},

	-- Preview colours in source code while editing
	'ap/vim-css-color',

	-- Nvim Treesitter configurations and abstraction layer
	{ 'nvim-treesitter/nvim-treesitter', build = ":TSUpdate" },

	--- Uncomment these if you want to manage LSP servers from neovim
	{'williamboman/mason.nvim'},
	{'williamboman/mason-lspconfig.nvim'},

	{'VonHeikemen/lsp-zero.nvim', branch = 'v3.x'},
	{'neovim/nvim-lspconfig'},
	{'hrsh7th/cmp-nvim-lsp'},
	{'hrsh7th/nvim-cmp'},
	{'L3MON4D3/LuaSnip'},
}

local opts = {}

require("lazy").setup(plugins, opts)
